/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PREESCOLAR (Excale 00)
/*
/*                          **** CONTEXTO ****
/*    ****** Respuestas de alumnos (ae), tutores (te) y profesores (pea) ********
/*
/*                     Ciclo escolar evaluado: 2006 - 2007
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CONTEXTO
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale00_2007_Alum_Cuest.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale00_2007_Alum_Cuest.txt
/*         as como el archivo Excale00_2007_Alum_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale00_2007_Alum_Cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale00_2007_Alum_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 5 DE AGOSTO DE 2008
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale00_2007_Alum_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbano Pblico"
                       2         ="Rural Pblico"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privados";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="Cuatro aos o menos"
                       2         ="Cinco aos"
                       3         ="Seis aos"
                       4         ="Siete aos o ms"
                       9         ="Respuesta omitida";
     VALUE edad1sF     99        ="Respuesta omitida";
     VALUE edad1scF    1         ="Cuatro aos o menos"
                       2         ="Cinco aos"
                       3         ="Seis o ms aos"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE ae1_7F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te000F
                       1         ="Madre o padre (tambin considere los tutores)"
                       2         ="Familiar [hermano(a), to(a), abuelo(a), primo(a), etctera]"
                       3         ="No familiar"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te1_5F
                       1         ="S"
                       0         ="No"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te006F
                       0         ="Ama de casa"
                       1         ="Ocupaciones elementales (albail, pen, campesina, comerciante no establecida, pescadora, empleada domstica, otra)"
                       2         ="Trabajadora manual (obrera, plomera, electricista, carpintera, jardinera, zapatera, etctera)"
                       3         ="Empleada de servicios - asalariada (mesera, polica, soldada, marina, chofer, otro)"
                       4         ="Prestadora de servicios - empleadora o duea (comerciante establecida, restaurantera, encargada de establecimiento, etc)"
                       5         ="Empleada de oficina (recepcionista, archivista, secretaria, capturista, burcrata, asistente, auxiliar, etctera)"
                       6         ="Tcnica superior universitario o profesional asociada (en mecnica, biotecnologa, comercializacin, mecatrnica, otro)"
                       7         ="Profesionista (mdica, ingeniera, abogada, profesora, dentista, otra profesin)"
                       8         ="Directivo de instituciones pblicas o privadas"
                       97        ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE te007F
                       0         ="No trabaja"
                       1         ="Ocupaciones elementales (albail, pen, campesino, comerciante no establecido, pescador, empleado domstico, otro)"
                       2         ="Trabajador manual (obrero, plomero, electricista, carpintero, jardinero, zapatero, etctera)"
                       3         ="Empleado de servicios - asalariado (mesero, polica, soldado, marino, chofer, otro)"
                       4         ="Prestador de servicios - empleador o dueo (comerciante establecido, restaurantero, encargado de establecimiento, etc)"
                       5         ="Empleado de oficina (recepcionista, archivista, secretaria, capturista, burcrata, asistente, auxiliar, etctera)"
                       6         ="Tcnico superior universitario o profesional asociado (en mecnica, biotecnologa, comercializacin, mecatrnica, otro)"
                       7         ="Profesionista (mdico, ingeniero, abogado, profesor, dentista, otra profesin)"
                       8         ="Directivo de instituciones pblicas o privadas"
                       97        ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE te008F
                       1         ="Loseta, alfombra, parquet, duela, etctera"
                       0         ="Cemento sin recubrimiento, tierra, tablones, etctera"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te9_13F
                       1         ="S"
                       0         ="No"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te14_17F
                       1         ="S hay"
                       0         ="No hay"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te018F
                       1         ="Primaria"
                       2         ="Secundaria"
                       3         ="Bachillerato o preparatoria"
                       4         ="Licenciatura (carrera universitaria)"
                       5         ="Posgrado (maestra o doctorado)"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te19_20F
                       0         ="No fue a la escuela"
                       1         ="Primaria"
                       2         ="Secundaria"
                       3         ="Bachillerato o preparatoria"
                       4         ="Licenciatura (carrera universitaria)"
                       5         ="Posgrado (maestra o doctorado)"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te21_28F
                       1         ="Casi nunca"
                       2         ="Pocas veces"
                       3         ="Muchas veces"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te029F
                       0         ="Ninguno"
                       1         ="Como 10 libros"
                       2         ="Como 25 libros"
                       3         ="Como 50 libros"
                       4         ="Como 100  ms libros"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te030F
                       0         ="Nunca"
                       1         ="Pocas veces"
                       2         ="Muchas veces"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te031F
                       1         ="S"
                       0         ="No"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te032F
                       1         ="Mal"
                       2         ="Regular"
                       3         ="Bien"
                       4         ="Muy bien"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te033F
                       0         ="0"
                       1         ="1"
                       2         ="2"
                       3         ="3"
                       4         ="4 aos o ms"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te034F
                       0         ="Ninguna"
                       1         ="Hasta 1 hora"
                       2         ="2  3 horas"
                       3         ="Ms de 3 horas"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te35_37F
                       1         ="S"
                       0         ="No"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te038F
                       1         ="Casi nunca"
                       2         ="Pocas veces"
                       3         ="Muchas veces"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te039F
                       1         ="Nunca o casi nunca"
                       2         ="A veces"
                       3         ="Casi siempre"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te040F
                       1         ="S"
                       0         ="No"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te041F
                       1         ="Nunca o casi nunca"
                       2         ="Pocas veces"
                       3         ="Muchas veces"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te042F
                       1         ="3 horas"
                       2         ="4 horas"
                       3         ="5 horas"
                       4         ="6 Horas"
                       5         ="7 horas o ms"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te043F
                       1         ="Pocas veces"
                       2         ="Muchas veces"
                       3         ="Siempre"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te044F
                       0         ="No hace las actividades"
                       1         ="Media hora"
                       2         ="1 hora"
                       3         ="Ms de 1 hora"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te045F
                       0         ="Ninguno"
                       1         ="1 da"
                       2         ="2  3 das"
                       3         ="4 das o ms"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te46_48F
                       1         ="Casi nunca"
                       2         ="A veces"
                       3         ="Casi siempre"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te049F
                       1         ="S"
                       0         ="No"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE te050F
                       1         ="Casi nunca"
                       2         ="A veces"
                       3         ="Casi siempre"
                       7         ="Respuesta perdida, no se contest el cuestionario de padres correspondiente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE pea1_5F
                       0         ="Nunca"
                       1         ="Casi nunca"
                       2         ="Algunas veces"
                       3         ="Frecuentemente"
                       7         ="Respuesta perdida, el docente no contest la informacin solicitada"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
RUN;



DATA INEE.Excale00_2007_Alum_Cuest;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       entest             $6
       alumno             6
       id_instr           $15
       sexo               3
       edad               8
       edadc              3
       edad1sep           8
       edad1sepc          3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       ae001              3
       ae002              3
       ae003              3
       ae004              3
       ae005              3
       ae006              3
       ae007              3
       te000              3
       te001              3
       te002              3
       te003              3
       te004              3
       te005              3
       te006              3
       te007              3
       te008              3
       te009              3
       te010              3
       te011              3
       te012              3
       te013              3
       te014              3
       te015              3
       te016              3
       te017              3
       te018              3
       te019              3
       te020              3
       te021              3
       te022              3
       te023              3
       te024              3
       te025              3
       te026              3
       te027              3
       te028              3
       te029              3
       te030              3
       te031              3
       te032              3
       te033              3
       te034              3
       te035              3
       te036              3
       te037              3
       te038              3
       te039              3
       te040              3
       te041              3
       te042              3
       te043              3
       te044              3
       te045              3
       te046              3
       te047              3
       te048              3
       te049              3
       te050              3
       pea01              3
       pea02              3
       pea03              3
       pea04              3
       pea05              3
       Dedicacion         3
       CCE                8
       Crianza            8
       Cobertura          8
       Equip              8
       Dedica_imp         3
       CCE_imp            3
       Crianz_imp         3
       Cobert_imp         3
       Equip_imp          3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
   ;

INFILE alum MISSOVER LINESIZE = 1100;
   INPUT
       nacional              1 - 1
       escuela               2 - 5
       id_ent                6 - 7
       nom_ent               8 - 26
       id_mod               27 - 27
       mod                  28 - 31
       entest               32 - 37
       alumno               38 - 42
       id_instr             43 - 57
       sexo                 58 - 58
       EDAD                 59 - 69
       EDADC                70 - 70
       Edad1sep             71 - 81
       Edad1SepC            82 - 82
       EDADN                83 - 83
       edad_ac              84 - 85
       mes_nac              86 - 87
       w_alu                88 - 98
       docente              99 - 103
       ae001               104 - 104
       ae002               105 - 105
       ae003               106 - 106
       ae004               107 - 107
       ae005               108 - 108
       ae006               109 - 109
       ae007               110 - 110
       te000               111 - 111
       te001               112 - 112
       te002               113 - 113
       te003               114 - 114
       te004               115 - 115
       te005               116 - 116
       te006               117 - 118
       te007               119 - 120
       te008               121 - 121
       te009               122 - 122
       te010               123 - 123
       te011               124 - 124
       te012               125 - 125
       te013               126 - 126
       te014               127 - 127
       te015               128 - 128
       te016               129 - 129
       te017               130 - 130
       te018               131 - 131
       te019               132 - 132
       te020               133 - 133
       te021               134 - 134
       te022               135 - 135
       te023               136 - 136
       te024               137 - 137
       te025               138 - 138
       te026               139 - 139
       te027               140 - 140
       te028               141 - 141
       te029               142 - 142
       te030               143 - 143
       te031               144 - 144
       te032               145 - 145
       te033               146 - 146
       te034               147 - 147
       te035               148 - 148
       te036               149 - 149
       te037               150 - 150
       te038               151 - 151
       te039               152 - 152
       te040               153 - 153
       te041               154 - 154
       te042               155 - 155
       te043               156 - 156
       te044               157 - 157
       te045               158 - 158
       te046               159 - 159
       te047               160 - 160
       te048               161 - 161
       te049               162 - 162
       te050               163 - 163
       pea01               164 - 164
       pea02               165 - 165
       pea03               166 - 166
       pea04               167 - 167
       pea05               168 - 168
       Dedicacion          169 - 169
       CCE                 170 - 180
       Crianza             181 - 191
       Cobertura           192 - 202
       Equip               203 - 213
       Dedica_imp          214 - 214
       CCE_imp             215 - 215
       Crianz_imp          216 - 216
       Cobert_imp          217 - 217
       Equip_imp           218 - 218
       wvarstrr            219 - 220
       w_fstr1             221 - 231
       w_fstr2             232 - 242
       w_fstr3             243 - 253
       w_fstr4             254 - 264
       w_fstr5             265 - 275
       w_fstr6             276 - 286
       w_fstr7             287 - 297
       w_fstr8             298 - 308
       w_fstr9             309 - 319
       w_fstr10            320 - 330
       w_fstr11            331 - 341
       w_fstr12            342 - 352
       w_fstr13            353 - 363
       w_fstr14            364 - 374
       w_fstr15            375 - 385
       w_fstr16            386 - 396
       w_fstr17            397 - 407
       w_fstr18            408 - 418
       w_fstr19            419 - 429
       w_fstr20            430 - 440
       w_fstr21            441 - 451
       w_fstr22            452 - 462
       w_fstr23            463 - 473
       w_fstr24            474 - 484
       w_fstr25            485 - 495
       w_fstr26            496 - 506
       w_fstr27            507 - 517
       w_fstr28            518 - 528
       w_fstr29            529 - 539
       w_fstr30            540 - 550
       w_fstr31            551 - 561
       w_fstr32            562 - 572
       w_fstr33            573 - 583
       w_fstr34            584 - 594
       w_fstr35            595 - 605
       w_fstr36            606 - 616
       w_fstr37            617 - 627
       w_fstr38            628 - 638
       w_fstr39            639 - 649
       w_fstr40            650 - 660
       w_fstr41            661 - 671
       w_fstr42            672 - 682
       w_fstr43            683 - 693
       w_fstr44            694 - 704
       w_fstr45            705 - 715
       w_fstr46            716 - 726
       w_fstr47            727 - 737
       w_fstr48            738 - 748
       w_fstr49            749 - 759
       w_fstr50            760 - 770
       w_fstr51            771 - 781
       w_fstr52            782 - 792
       w_fstr53            793 - 803
       w_fstr54            804 - 814
       w_fstr55            815 - 825
       w_fstr56            826 - 836
       w_fstr57            837 - 847
       w_fstr58            848 - 858
       w_fstr59            859 - 869
       w_fstr60            870 - 880
       w_fstr61            881 - 891
       w_fstr62            892 - 902
       w_fstr63            903 - 913
       w_fstr64            914 - 924
       w_fstr65            925 - 935
       w_fstr66            936 - 946
       w_fstr67            947 - 957
       w_fstr68            958 - 968
       w_fstr69            969 - 979
       w_fstr70            980 - 990
       w_fstr71            991 - 1001
       w_fstr72           1002 - 1012
       w_fstr73           1013 - 1023
       w_fstr74           1024 - 1034
       w_fstr75           1035 - 1045
       w_fstr76           1046 - 1056
       w_fstr77           1057 - 1067
       w_fstr78           1068 - 1078
       w_fstr79           1079 - 1089
       w_fstr80           1090 - 1100
;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad-Densidad de poblacin)"
       alumno      = "Identificador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       EDAD        = "Edad del alumno al mes de mayo de 2007, en aos (al momento de la aplicacin)"
       EDADC       = "Edad del alumno al mes de mayo de 2007, codificada (al momento de la aplicacin)"
       Edad1sep    = "Edad del alumno al mes de septiembre de 2006, en aos (al inicio del ciclo escolar)"
       Edad1SepC   = "Edad del alumno al mes de septiembre de 2006, codificada (al inicio del ciclo escolar)"
       EDADN       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       ae001       = "Te gusta estar con tu maestra?"
       ae002       = "Tu maestra te felicita cuando haces bien las cosas?"
       ae003       = "Cuando un nio se porta mal, la maestra platica con l?"
       ae004       = "Tu maestra te hace caso cuando le hablas?"
       ae005       = "Te llevas bien con tus compaeros del saln?"
       ae006       = "En tu saln, hay nios que destruyen a propsito el material?"
       ae007       = "En tu saln, hay nios que se llevan cosas que no son suyas?"
       te000       = "Cul es el parentesco que tiene con el nio?"
       te001       = "El nio aprendi a hablar en alguna lengua indgena?"
       te002       = "En la casa donde vive el nio, se habla la mayor parte del tiempo alguna lengua indgena?"
       te003       = "El nio necesita ayuda especial para aprender?"
       te004       = "Con quin vive el nio? Con su mam"
       te005       = "Con quin vive el nio? Con su pap"
       te006       = "En qu trabaja la mam o tutora del nio?"
       te007       = "En qu trabaja el pap o tutor del nio?"
       te008       = "De que material es la mayor parte del piso que est dentro de la casa donde vive el nio?"
       te009       = "Servicios que hay en la casa donde vive el nio. Drenaje"
       te010       = "Servicios que hay en la casa donde vive el nio. Lnea telefnica"
       te011       = "Servicios que hay en la casa donde vive el nio. Televisin  por cable o satlite"
       te012       = "Servicios que hay en la casa donde vive el nio. Conexin a internet"
       te013       = "Su familia recibe apoyo del programa Oportunidades?"
       te014       = "Bienes que existen en la casa donde vive el nio. Computadora"
       te015       = "Bienes que existen en la casa donde vive el nio. Auto, coche o camioneta"
       te016       = "Bienes que existen en la casa donde vive el nio. Lavadora"
       te017       = "Bienes que existen en la casa donde vive el nio. Horno de microondas"
       te018       = "Hasta qu nivel educativo le gustara que estudiara el nio?"
       te019       = "Hasta qu nivel educativo termin la madre o tutora del nio?"
       te020       = "Hasta qu nivel educativo termin el padre o tutor del nio?"
       te021       = "El nio tiene los materiales que pide el docente?"
       te022       = "Con qu frecuencia los paps o tutores leen algn peridico, revistas, libros, etctera?"
       te023       = "En una semana normal,los paps o algn adulto realizan alguna de las siguientes actividades con el nio? Leer para el nio"
       te024       = "En una semana normal,los paps o algn adulto realizan alguna de las siguientes actividades con el nio? Ensearle letras, palabras o nmeros"
       te025       = "En una semana normal,los paps o algn adulto realizan alguna de las siguientes actividades con el nio? Contarle una historia"
       te026       = "En una semana normal,los paps o algn adulto realizan alguna de las siguientes actividades con el nio? Ensearle canciones"
       te027       = "En una semana normal,los paps o algn adulto realizan alguna de las siguientes actividades con el nio? Trabajar en actividades manuales o artsticas"
       te028       = "En una semana normal,los paps o algn adulto realizan alguna de las siguientes actividades con el nio? Jugar con el nio"
       te029       = "Aproximadamente, cuntos libros hay en la casa del nio?"
       te030       = "El nio pelea con alguno de sus paps o tutores?"
       te031       = "Cuando el nio tiene problemas con sus padres, duran mucho tiempo enojados?"
       te032       = "Cmo se llevan las personas que viven en la casa donde vive el nio?"
       te033       = "Cuntos aos, adems de ste, el nio ha ido a la escuela? (Guardera, Cendi, estancia infantil, kinder, etctera)"
       te034       = "Aproximadamente, cuntas horas al da el nio ve televisin y/o juega videojuegos?"
       te035       = "El nio practica algn deporte (futbol, bisbol, natacin u otro) fuera de la escuela?"
       te036       = "El nio realiza alguna actividad artstica (baile, msica, u otra) fuera de la escuela?"
       te037       = "El nio toma clases de algn idioma extranjero (ingls, francs u otro) fuera de la escuela?"
       te038       = "Con qu frecuencia el nio revisa, hojea o lee libros? (Considere tambin cuentos, historietas, revistas u otros)"
       te039       = "Con qu frecuencia asiste el nio a ferias, fiestas de pueblo, exposiciones, museo, cine u otra actividad cultural?"
       te040       = "Colabora el nio en la limpieza de la casa guardando sus juguetes, ordenando cosas o realizando otras actividades?"
       te041       = "Con qu frecuencia el nio falta a la escuela?"
       te042       = "Cunto tiempo pasa el nio en la escuela?"
       te043       = "El nio realiza las actividades que deja el docente para hacer fuera de la escuela?"
       te044       = "En general, cunto tiempo al da dedica el nio a hacer estas actividades?"
       te045       = "Aproximadamente, cuantos das a la semana hace tarea el nio?"
       te046       = "Le gusta al nio ir a la escuela?"
       te047       = "El docente del nio falta a clases?"
       te048       = "El docente del nio llega tarde a clases?"
       te049       = "El docente tiene una buena relacin con los paps o tutores del nio?"
       te050       = "El docente muestra inters y apoya a los nios?"
       pea01       = "El nio ha golpeado a algn compaero?"
       pea02       = "El nio ha arrebatado cosas a algn compaero?"
       pea03       = "El nio se ha burlado de algn compaero?"
       pea04       = "El nio muestra falta de higiene y cuidado corporal?"
       pea05       = "El nio presenta huellas de maltrato fsico y/o emocional?"
       Dedicacion  = "Dedicacin de enseanza"
       CCE         = "Capital cultural escolar"
       Crianza     = "Actividades de crianza"
       Cobertura   = "Cobertura curricular"
       Equip       = "Equipamiento escolar"
       Dedica_imp  = "Indicadora de los valores que fueron imputados"
       CCE_imp     = "Indicadora de los valores que fueron imputados"
       Crianz_imp  = "Indicadora de los valores que fueron imputados"
       Cobert_imp  = "Indicadora de los valores que fueron imputados"
       Equip_imp   = "Indicadora de los valores que fueron imputados"
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       entest             $char6.
       alumno             5.
       id_instr           $char15.
       sexo               sexoF.
       edad               edadF.
       edadc              edadcF.
       edad1sep           edad1sF.
       edad1sepc          edad1scF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       ae001              ae1_7F.
       ae002              ae1_7F.
       ae003              ae1_7F.
       ae004              ae1_7F.
       ae005              ae1_7F.
       ae006              ae1_7F.
       ae007              ae1_7F.
       te000              te000F.
       te001              te1_5F.
       te002              te1_5F.
       te003              te1_5F.
       te004              te1_5F.
       te005              te1_5F.
       te006              te006F.
       te007              te007F.
       te008              te008F.
       te009              te9_13F.
       te010              te9_13F.
       te011              te9_13F.
       te012              te9_13F.
       te013              te9_13F.
       te014              te14_17F.
       te015              te14_17F.
       te016              te14_17F.
       te017              te14_17F.
       te018              te018F.
       te019              te19_20F.
       te020              te19_20F.
       te021              te21_28F.
       te022              te21_28F.
       te023              te21_28F.
       te024              te21_28F.
       te025              te21_28F.
       te026              te21_28F.
       te027              te21_28F.
       te028              te21_28F.
       te029              te029F.
       te030              te030F.
       te031              te031F.
       te032              te032F.
       te033              te033F.
       te034              te034F.
       te035              te35_37F.
       te036              te35_37F.
       te037              te35_37F.
       te038              te038F.
       te039              te039F.
       te040              te040F.
       te041              te041F.
       te042              te042F.
       te043              te043F.
       te044              te044F.
       te045              te045F.
       te046              te46_48F.
       te047              te46_48F.
       te048              te46_48F.
       te049              te049F.
       te050              te050F.
       pea01              pea1_5F.
       pea02              pea1_5F.
       pea03              pea1_5F.
       pea04              pea1_5F.
       pea05              pea1_5F.
       CCE                2.
       Crianza            2.
       Cobertura          2.
       Equip              2.
       wvarstrr           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(4)  sexo edadc edad1sepc edadn;
   DO  i=1 TO 4;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(4)  edad edad1sep edad_ac mes_nac;
   DO  i=1 TO 4;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(61)
                   ae001 ae002 ae003 ae004 ae005 ae006 ae007 te000 te001 te002
                   te003 te004 te005 te008 te009 te010 te011 te012 te013 te014
                   te015 te016 te017 te018 te019 te020 te021 te022 te023 te024
                   te025 te026 te027 te028 te029 te030 te031 te032 te033 te034
                   te035 te036 te037 te038 te039 te040 te041 te042 te043 te044
                   te045 te046 te047 te048 te049 te050 pea01 pea02 pea03 pea04 pea05;
   DO  i=1 TO 61;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;


   ARRAY perdidos4(2)
                    te006 te007;
   DO  i=1 TO 2;
          IF perdidos4{i} = 97   THEN  perdidos4{i} = .N;
          IF perdidos4{i} = 98   THEN  perdidos4{i} = .M;
          IF perdidos4{i} = 99   THEN  perdidos4{i} = .S;
   END;

   drop i;
RUN;
